==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/CellRangeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellRangeDescription } from "./CellRangeDescription";
/**
 * @hidden
 */
var CellRangeDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CellRangeDescriptionMetadata, _super);
    function CellRangeDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CellRangeDescriptionMetadata.b = function (a) {
        if (CellRangeDescriptionMetadata.a == null) {
            CellRangeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CellRangeDescriptionMetadata.c(CellRangeDescriptionMetadata.a);
        }
        if (a.g(CellRangeDescriptionMetadata.a)) {
            return;
        }
        a.s(CellRangeDescriptionMetadata.a);
    };
    CellRangeDescriptionMetadata.c = function (a) {
        a.item("StartColumn", "Number:int");
        a.item("EndColumn", "Number:int");
        a.item("StartRow", "Number:int");
        a.item("EndRow", "Number:int");
    };
    CellRangeDescriptionMetadata.d = function (a) {
        CellRangeDescriptionMetadata.b(a);
        a.u("CellRange", function () { return new CellRangeDescription(); });
        a.t("CellRange", CellRangeDescriptionMetadata.a);
    };
    CellRangeDescriptionMetadata.$t = markType(CellRangeDescriptionMetadata, 'CellRangeDescriptionMetadata');
    CellRangeDescriptionMetadata.a = null;
    return CellRangeDescriptionMetadata;
}(Base));
export { CellRangeDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/CellRangeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellRangeDescription } from "./CellRangeDescription";
/**
 * @hidden
 */
var CellRangeDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CellRangeDescriptionMetadata, _super);
    function CellRangeDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CellRangeDescriptionMetadata.b = function (a) {
        if (CellRangeDescriptionMetadata.a == null) {
            CellRangeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CellRangeDescriptionMetadata.c(CellRangeDescriptionMetadata.a);
        }
        if (a.j(CellRangeDescriptionMetadata.a)) {
            return;
        }
        a.y(CellRangeDescriptionMetadata.a);
    };
    CellRangeDescriptionMetadata.c = function (a) {
        a.item("StartColumn", "Number:int");
        a.item("EndColumn", "Number:int");
        a.item("StartRow", "Number:int");
        a.item("EndRow", "Number:int");
    };
    CellRangeDescriptionMetadata.d = function (a) {
        CellRangeDescriptionMetadata.b(a);
        a.aa("CellRange", function () { return new CellRangeDescription(); });
        a.z("CellRange", CellRangeDescriptionMetadata.a);
    };
    CellRangeDescriptionMetadata.$t = markType(CellRangeDescriptionMetadata, 'CellRangeDescriptionMetadata');
    CellRangeDescriptionMetadata.a = null;
    return CellRangeDescriptionMetadata;
}(Base));
export { CellRangeDescriptionMetadata };
